@@ -1,11 +1,5 @@
-# -*- coding: utf-8 -*-
 from django.test import TestCase
-try:
-    from django.utils.encoding import smart_unicode
-except ImportError:
-    from django.utils.encoding import smart_text as smart_unicode
-
-from datetime import datetime
+from django.utils import timezone
 
 from pagseguro.models import Checkout, Transaction, TransactionHistory
 
@@ -15,11 +9,11 @@ class CheckoutTest(TestCase):
     def test_create_model(self):
         checkout = Checkout.objects.create(
             code='007',
-            date=datetime.now(),
+            date=timezone.now(),
             success=True
         )
         self.assertEqual(
-            smart_unicode(checkout), '{0}'.format(checkout.pk)
+            str(checkout), '{0}'.format(checkout.pk)
         )
 
 
@@ -30,11 +24,11 @@ class TransactionTest(TestCase):
             code='007',
             reference='nothing',
             status='aguardando',
-            date=datetime.now(),
-            last_event_date=datetime.now()
+            date=timezone.now(),
+            last_event_date=timezone.now()
         )
         self.assertEqual(
-            smart_unicode(transaction), transaction.code
+            str(transaction), transaction.code
         )
 
 
@@ -45,16 +39,16 @@ class TransactionHistoryTest(TestCase):
             code='007',
             reference='nothing',
             status='aguardando',
-            date=datetime.now(),
-            last_event_date=datetime.now()
+            date=timezone.now(),
+            last_event_date=timezone.now()
         )
         tx_history = TransactionHistory.objects.create(
             transaction=transaction,
-            date=datetime.now(),
+            date=timezone.now(),
             status='aguardando'
         )
         self.assertEqual(
-            smart_unicode(tx_history),
+            str(tx_history),
             '{0} - {1} - {2}'.format(
                 tx_history.transaction, tx_history.status, tx_history.date
             )
