@@ -1,13 +1,10 @@
-# -*- coding: utf-8 -*-
+import responses
 from django.test import TestCase
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 
-import httpretty
-
-from pagseguro.settings import NOTIFICATION_URL, CHECKOUT_URL
-from pagseguro.api import PagSeguroItem, PagSeguroApi
+from pagseguro.api import PagSeguroApi, PagSeguroItem
 from pagseguro.models import Transaction, TransactionHistory
-
+from pagseguro.settings import CHECKOUT_URL, NOTIFICATION_URL
 
 notification_response_xml = '''<?xml version="1.0" encoding="UTF-8"?>
 <transaction>
@@ -84,7 +81,7 @@ class PagSeguroSignalsTest(TestCase):
             'notificationType': 'transaction'
         }
 
-    @httpretty.activate
+    @responses.activate
     def test_checkout_realizado(self):
         from pagseguro.signals import checkout_realizado
 
@@ -101,8 +98,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        httpretty.register_uri(
-            httpretty.POST,
+        responses.add(
+            responses.POST,
             CHECKOUT_URL,
             body=checkout_response_xml,
             status=200,
@@ -125,7 +122,7 @@ class PagSeguroSignalsTest(TestCase):
         # load notification
         pagseguro_api.checkout()
 
-    @httpretty.activate
+    @responses.activate
     def test_checkout_realizado_com_sucesso(self):
         from pagseguro.signals import checkout_realizado_com_sucesso
 
@@ -142,8 +139,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        httpretty.register_uri(
-            httpretty.POST,
+        responses.add(
+            responses.POST,
             CHECKOUT_URL,
             body=checkout_response_xml,
             status=200,
@@ -166,7 +163,7 @@ class PagSeguroSignalsTest(TestCase):
         # load notification
         pagseguro_api.checkout()
 
-    @httpretty.activate
+    @responses.activate
     def test_checkout_realizado_com_erro(self):
         from pagseguro.signals import checkout_realizado_com_erro
 
@@ -183,8 +180,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        httpretty.register_uri(
-            httpretty.POST,
+        responses.add(
+            responses.POST,
             CHECKOUT_URL,
             body='Unauthorized',
             status=401,
@@ -207,7 +204,7 @@ class PagSeguroSignalsTest(TestCase):
         # load notification
         pagseguro_api.checkout()
 
-    @httpretty.activate
+    @responses.activate
     def test_notificacao_recebida(self):
         from pagseguro.signals import notificacao_recebida
 
@@ -218,8 +215,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml,
             status=200,
@@ -232,7 +229,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @httpretty.activate
+    @responses.activate
     def test_notificacao_status_aguardando(self):
         from pagseguro.signals import notificacao_status_aguardando
 
@@ -243,8 +240,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml,
             status=200,
@@ -257,7 +254,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @httpretty.activate
+    @responses.activate
     def test_notificacao_status_em_analise(self):
         from pagseguro.signals import notificacao_status_em_analise
 
@@ -268,8 +265,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>2</status>'
@@ -284,7 +281,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @httpretty.activate
+    @responses.activate
     def test_notificacao_status_pago(self):
         from pagseguro.signals import notificacao_status_pago
 
@@ -295,8 +292,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>3</status>'
@@ -311,7 +308,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @httpretty.activate
+    @responses.activate
     def test_notificacao_status_disponivel(self):
         from pagseguro.signals import notificacao_status_disponivel
 
@@ -322,8 +319,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>4</status>'
@@ -338,7 +335,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @httpretty.activate
+    @responses.activate
     def test_notificacao_status_em_disputa(self):
         from pagseguro.signals import notificacao_status_em_disputa
 
@@ -349,8 +346,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>5</status>'
@@ -365,7 +362,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @httpretty.activate
+    @responses.activate
     def test_notificacao_status_devolvido(self):
         from pagseguro.signals import notificacao_status_devolvido
 
@@ -376,8 +373,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>6</status>'
@@ -392,7 +389,7 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @httpretty.activate
+    @responses.activate
     def test_notificacao_status_cancelado(self):
         from pagseguro.signals import notificacao_status_cancelado
 
@@ -403,8 +400,8 @@ class PagSeguroSignalsTest(TestCase):
             )
 
         # mock requests
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>7</status>'
@@ -419,11 +416,65 @@ class PagSeguroSignalsTest(TestCase):
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
 
-    @httpretty.activate
+    @responses.activate
+    def test_notificacao_status_debitado(self):
+        from pagseguro.signals import notificacao_status_debitado
+
+        # load signal function
+        def load_signal(sender, transaction, **kwargs):
+            self.assertEqual(
+                transaction['status'], '8'
+            )
+
+        # mock requests
+        responses.add(
+            responses.GET,
+            NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
+            body=notification_response_xml.replace(
+                '<status>1</status>', '<status>8</status>'
+            ),
+            status=200,
+        )
+
+        # connect to signal
+        notificacao_status_debitado.connect(load_signal)
+
+        # load notification
+        response = self.client.post(self.url, self.post_params)
+        self.assertEqual(response.status_code, 200)
+
+    @responses.activate
+    def test_notificacao_status_retencao_temporaria(self):
+        from pagseguro.signals import notificacao_status_retencao_temporaria
+
+        # load signal function
+        def load_signal(sender, transaction, **kwargs):
+            self.assertEqual(
+                transaction['status'], '9'
+            )
+
+        # mock requests
+        responses.add(
+            responses.GET,
+            NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
+            body=notification_response_xml.replace(
+                '<status>1</status>', '<status>9</status>'
+            ),
+            status=200,
+        )
+
+        # connect to signal
+        notificacao_status_retencao_temporaria.connect(load_signal)
+
+        # load notification
+        response = self.client.post(self.url, self.post_params)
+        self.assertEqual(response.status_code, 200)
+
+    @responses.activate
     def test_update_transaction(self):
         # mock requests
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml,
             status=200,
@@ -461,9 +512,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'aguardando')
 
         # mock requests
-        httpretty.reset()
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.reset()
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>2</status>'
@@ -491,9 +542,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'em_analise')
 
         # mock requests
-        httpretty.reset()
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.reset()
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>3</status>'
@@ -527,9 +578,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'pago')
 
         # mock requests
-        httpretty.reset()
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.reset()
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>4</status>'
@@ -569,9 +620,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'disponivel')
 
         # mock requests
-        httpretty.reset()
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.reset()
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>5</status>'
@@ -617,9 +668,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'em_disputa')
 
         # mock requests
-        httpretty.reset()
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.reset()
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>6</status>'
@@ -671,9 +722,9 @@ class PagSeguroSignalsTest(TestCase):
         self.assertEqual(transaction.status, 'devolvido')
 
         # mock requests
-        httpretty.reset()
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.reset()
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(self.notificationCode),
             body=notification_response_xml.replace(
                 '<status>1</status>', '<status>7</status>'
