@@ -1,13 +1,9 @@
-# -*- coding: utf-8 -*-
+import responses
 from django.test import TestCase
-from django.core.urlresolvers import reverse
-
-import httpretty
-import six
+from django.urls import reverse
 
 from pagseguro.settings import NOTIFICATION_URL
 
-
 notification_response_xml = '''<?xml version="1.0" encoding="UTF-8"?>
 <transaction>
   <date>2014-06-05T22:52:49.000-03:00</date>
@@ -92,11 +88,11 @@ class ReceiveNotificationViewTest(TestCase):
         )
         self.assertEqual(response.status_code, 400)
 
-    @httpretty.activate
+    @responses.activate
     def test_render_invalid_notification(self):
         # mock requests
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(
                 'A5182C-C9EF48EF48D2-1FF4AF6FAC82-EB2948'
             ),
@@ -106,13 +102,17 @@ class ReceiveNotificationViewTest(TestCase):
 
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 400)
-        self.assertEqual(response.content, six.b('Notificação inválida.'))
+        self.assertContains(
+            response,
+            'Notificação inválida.',
+            status_code=400
+        )
 
-    @httpretty.activate
+    @responses.activate
     def test_render(self):
         # mock requests
-        httpretty.register_uri(
-            httpretty.GET,
+        responses.add(
+            responses.GET,
             NOTIFICATION_URL + '/{0}'.format(
                 'A5182C-C9EF48EF48D2-1FF4AF6FAC82-EB2948'
             ),
@@ -122,6 +122,8 @@ class ReceiveNotificationViewTest(TestCase):
 
         response = self.client.post(self.url, self.post_params)
         self.assertEqual(response.status_code, 200)
-        self.assertEqual(
-            response.content, six.b('Notificação recebida com sucesso.')
+        self.assertContains(
+            response,
+            'Notificação recebida com sucesso.',
+            status_code=200
         )
